@@ -8,6 +8,7 @@ import grp
 import logging
 import os
 from os import path
+import platform
 import pwd
 import re
 import subprocess
@@ -22,6 +23,22 @@ warnings.filterwarnings("ignore", category=DeprecationWarning)
 LOGGER = logging.getLogger(__name__)
 
 
+def operating_system():
+    """Return a string identifying the operating system the application
+    is running on.
+
+    :rtype: str
+
+    """
+    if platform.system() == 'Darwin':
+        return 'OS X Version %s' % platform.mac_ver()[0]
+    distribution = ' '.join(platform.linux_distribution()).strip()
+    os_platform = platform.platform(True, True)
+    if distribution:
+        os_platform += ' (%s)' % distribution
+    return os_platform
+
+
 class Daemon(object):
     """Daemonize the helper application, putting it in a forked background
     process.
